#!/usr/bin/perl

###############################################################################
#
# FileLister - an open source alternative for listing files/directories
#              with an easy navigateable interface.
#
# Copyright (c) by  Oliver Falk, June 2003
#                   oliver@linux-kernel.at
#
# Changes are welcome, but please inform me about those!
#
###############################################################################

###############################################################################
#
# $Id: rpminfo.pl,v 1.41 2004/11/26 09:17:57 oliver Exp $
#
# $Log: rpminfo.pl,v $
# Revision 1.41  2004/11/26 09:17:57  oliver
# * Name changed...
#
# Revision 1.40  2004/07/06 13:03:34  oliver
# +) bumped: version number to 1.40
#
# Revision 1.1.1.1  2004/07/06 11:01:35  oliver
# * Initial import after cvs was lost
#
# Revision 1.11  2004/01/12 16:25:02  oliver
# * Make all pages XHTML 1.0 valid
#
# Revision 1.10  2004/01/08 10:35:25  oliver
# + One more typo in copyright statement
#
# Revision 1.9  2004/01/08 09:51:36  oliver
# +/- Beautify... Kick out some comments.
#
# Revision 1.8  2004/01/08 09:48:50  oliver
# + Convert < and > to &lt; and &gt; using regex
#
# Revision 1.7  2003/10/03 10:47:51  oliver
# + Add inline documentation...
#
# Revision 1.6  2003/10/01 13:50:38  oliver
# + Fix bug with changelog... It wasn't printed...  .=  will not work. :))))
#
# Revision 1.5  2003/10/01 13:33:59  oliver
# + RPMInfo uses now Template::Toolkit
#
# Revision 1.4  2003/09/30 16:06:30  oliver
# +/- Use the configfile, instead of local variables...
#
# Revision 1.3  2003/07/28 13:07:32  oliver
# + Add comments in the header of the files; Copyright, CVS Log, CVS Id, ...
#
###############################################################################

# Load Modules we use.
use strict;
use warnings;
require Template;
use CGI qw/:standard/;
use YAML::LoadFileCached;

# Set Version - comes from CVS.
(our $VERSION) = '$Revision: 1.41 $' =~ /([\d.]+)/;

# Create a new TT2 object.
my $tt = Template->new;

# Set static variable configfile and load it using YAML.
my $configfile = 'config/FileLister.yaml.conf';
my $config = LoadFileCached($configfile);

# Helper for the background color
my $bg_color;

# Some security checks - double dots are simply ignored and if no path is
# specified, set it to "/" which is not the partition "/", but our root
# releative to the path from the config file.
my $file = param('file') || '/';
$file =~ s/\.\.//g;
$file =~ s/(\/\/)/\//g;

# Check the architecture and set the background color.
# Variables have been declared in the config file, but arn't used yet.
if    ($file =~ m/i.86\./)  { $bg_color = "#b0ffb0"; }
elsif ($file =~ m/alpha\./) { $bg_color = "#ffb0ff"; }
elsif ($file =~ m/sparc\./) { $bg_color = "#b0b0ff"; }
elsif ($file =~ m/src\./)   { $bg_color = "#CCCCCC"; }
else                        { $bg_color = "#EEEEEE"; }

# Quick hack number one in this file....
# I don't document it, because it's tooo easy to understand - isn't it? :-P
open(FILE, "rpm -qpi $config->{'path_and_url_stuff'}->{'path'}/$file|");
my $rpminfo;
while (my $line = <FILE>) {
    $line =~ s/</&lt;/;
    $line =~ s/>/&gt;/;
    $rpminfo .= $line;
}

close(FILE);

# Quick hack number two in this file....
# I don't document it, because it's tooo easy to understand - isn't it? :-P
open(FILE, "rpm -qp --changelog $config->{'path_and_url_stuff'}->{'path'}/$file|");
my $rpmchangelog;
while (my $line = <FILE>) {
    $line =~ s/</&lt;/;
    $line =~ s/>/&gt;/;
    $rpmchangelog .= $line;
}

close(FILE);

# Finally create a hash with all the data, we want to display...
my %main_data = ( title            => "RPMInfo $VERSION",
                  version          => $VERSION,
                  bg_color         => $bg_color,
                  stylesheet       => $config->{'style_stuff'}->{'stylesheet'},
                  rpminfo          => $rpminfo,
                  rpmchangelog     => $rpmchangelog );

# Hand it over to Template::Toolkit - I love that thingy. :-)
$tt->process('templates/rpminfo.tpl', \%main_data) || die $tt->error;
